<?php

/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
function rws_event_lists_posttype() {

    $labels = array(
        'name'                => __( 'Event Lists', 'rws-iw' ),
        'singular_name'       => __( 'Event List', 'rws-iw' ),
        'add_new'             => _x( 'Add New Event List', 'rws-iw', 'rws-iw' ),
        'add_new_item'        => __( 'Add New Event List', 'rws-iw' ),
        'edit_item'           => __( 'Edit Event List', 'rws-iw' ),
        'new_item'            => __( 'New Event List', 'rws-iw' ),
        'view_item'           => __( 'View Event List', 'rws-iw' ),
        'search_items'        => __( 'Search Event Lists', 'rws-iw' ),
        'not_found'           => __( 'No Event Lists found', 'rws-iw' ),
        'not_found_in_trash'  => __( 'No Event Lists found in Trash', 'rws-iw' ),
        'parent_item_colon'   => __( 'Parent Event List:', 'rws-iw' ),
        'menu_name'           => __( 'Event Lists', 'rws-iw' ),
    );

    $args = array(
        'labels'              => $labels,
        'hierarchical'        => false,
        'description'         => 'Custom Post Type Created for Press Releases',
        'taxonomies'          => array(),
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_admin_bar'   => true,
        'menu_position'       => null,
        'menu_icon'           => 'dashicons-format-image',
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive'         => false,  //true
        'query_var'           => true,
        'can_export'          => true,
        'rewrite'             => true,
        'capability_type'     => 'post',
        'supports'            => array( 'title', 'editor', 'thumbnail', 'comments')
    );

    register_post_type( 'event-lists', $args );
}

add_action( 'init', 'rws_event_lists_posttype' );


/**
 * Create a taxonomy
 *
 * @uses  Inserts new taxonomy object into the list
 * @uses  Adds query vars
 *
 * @param string  Name of taxonomy object
 * @param array|string  Name of the object type for the taxonomy object.
 * @param array|string  Taxonomy arguments
 * @return null|WP_Error WP_Error if errors, otherwise null.
 */
function event_lists_taxonomy() {

    $labels = array(
        'name'                  => _x( 'Event Lists Categories', 'Taxonomy plural name', 'rws-iw' ),
        'singular_name'         => _x( 'Event List Category', 'Taxonomy singular name', 'rws-iw' ),
        'search_items'          => __( 'Search Event Lists Categories', 'rws-iw' ),
        'popular_items'         => __( 'Popular Event Lists Categories', 'rws-iw' ),
        'all_items'             => __( 'All Event Lists Categories', 'rws-iw' ),
        'parent_item'           => __( 'Parent Event List Category', 'rws-iw' ),
        'parent_item_colon'     => __( 'Parent Event List Category', 'rws-iw' ),
        'edit_item'             => __( 'Edit Event List Category', 'rws-iw' ),
        'update_item'           => __( 'Update Event List Category', 'rws-iw' ),
        'add_new_item'          => __( 'Add New Event List Category', 'rws-iw' ),
        'new_item_name'         => __( 'New Event List Category Name', 'rws-iw' ),
        'add_or_remove_items'   => __( 'Add or remove Event Lists Categories', 'rws-iw' ),
        'choose_from_most_used' => __( 'Choose from most used Event Lists Categories', 'rws-iw' ),
        'menu_name'             => __( 'Event List Category', 'rws-iw' ),
    );

    $args = array(
        'labels'            => $labels,
        'public'            => true,
        'show_in_nav_menus' => true,
        'show_admin_column' => false,
        'hierarchical'      => true,
        'show_tagcloud'     => true,
        'show_ui'           => true,
        'query_var'         => true,
        'rewrite'           => true,
        'query_var'         => true,
        'capabilities'      => array(),
    );

    register_taxonomy( 'event-lists-category', array( 'event-lists' ), $args );
}

add_action( 'init', 'event_lists_taxonomy' );



add_filter('manage_event-lists_posts_columns', 'rws_head_only_event_lists');
add_action('manage_event-lists_posts_custom_column', 'rws_content_only_event_lists', 10, 2);
 
//adding column in the listing of the our mentors
function rws_head_only_event_lists($defaults) {
    $defaults['featured_image'] = 'Event Image';
    return $defaults;
}
function rws_content_only_event_lists($column_name, $post_ID) {
    if ($column_name == 'featured_image') {
        $post_thumbnail_id = get_post_thumbnail_id($post_ID);
        if ($post_thumbnail_id) {
            $post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'featured_preview');
            echo "<img src='".$post_thumbnail_img[0]."' width='80'/>";
        }
    }
}