<?php

/**
 * Adds a meta box to the post editing screen
 */
function prfx_custom_meta() {
    add_meta_box( 'prfx_meta', __( 'Auto Values', 'rws-iw' ), 'prfx_meta_callback', 'espresso_events' , 'side', 'high' );
}
add_action( 'add_meta_boxes', 'prfx_custom_meta' );

/**
 * Outputs the content of the meta box
 */
function prfx_meta_callback( $post ) {
    wp_nonce_field( basename( __FILE__ ), 'prfx_nonce' );
    $prfx_stored_meta = get_post_meta( $post->ID );
    ?>
    <p>
        <label for="es_date" class="prfx-row-title"><?php _e( 'Event Start Date', 'rws-iw' )?></label>
        <input type="text" class="iw-esd" name="es_date" id="es_date" value="<?php if ( isset ( $prfx_stored_meta['es_date'] ) ) echo $prfx_stored_meta['es_date'][0]; ?>" readonly />
    </p>

    <p>
        <label for="es_city" class="prfx-row-title"><?php _e( 'City', 'rws-iw' )?></label>
        <br/>
        <input type="text" class="iw-escity" name="es_city" id="es_city" value="<?php if ( isset ( $prfx_stored_meta['es_city'] ) ) echo $prfx_stored_meta['es_city'][0]; ?>" readonly/>
    </p>
 
    <?php
}

/**
 * Saves the custom meta input
 */
function prfx_meta_save( $post_id ) {
 
    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'prfx_nonce' ] ) && wp_verify_nonce( $_POST[ 'prfx_nonce' ], basename( __FILE__ ) ) ) ? 'true' : 'false';
 
    // Exits script depending on save status
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }
 
    // Checks for input and sanitizes/saves if needed
    if( isset( $_POST[ 'es_date' ] ) ) {
        update_post_meta( $post_id, 'es_date', sanitize_text_field( $_POST[ 'es_date' ] ) );
    }else{
    	delete_post_meta( $post_id, 'es_date', $_POST[ 'es_date' ] );
    }

    if( isset( $_POST[ 'es_city' ] ) ) {
        update_post_meta( $post_id, 'es_city', sanitize_text_field( $_POST[ 'es_city' ] ) );
    }else{
    	delete_post_meta( $post_id, 'es_city', $_POST[ 'es_city' ] );
    }
 
}
add_action( 'save_post', 'prfx_meta_save' );
