<?php

/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
function rws_event_posttype() {

    $labels = array(
        'name'                => __( 'Events', 'rws-iw' ),
        'singular_name'       => __( 'Event', 'rws-iw' ),
        'add_new'             => _x( 'Add New Event', 'rws-iw', 'rws-iw' ),
        'add_new_item'        => __( 'Add New Event', 'rws-iw' ),
        'edit_item'           => __( 'Edit Event', 'rws-iw' ),
        'new_item'            => __( 'New Event', 'rws-iw' ),
        'view_item'           => __( 'View Event', 'rws-iw' ),
        'search_items'        => __( 'Search Events', 'rws-iw' ),
        'not_found'           => __( 'No Events found', 'rws-iw' ),
        'not_found_in_trash'  => __( 'No Events found in Trash', 'rws-iw' ),
        'parent_item_colon'   => __( 'Parent Event:', 'rws-iw' ),
        'menu_name'           => __( 'Events', 'rws-iw' ),
    );

    $args = array(
        'labels'              => $labels,
        'hierarchical'        => false,
        'description'         => 'Custom Post Type Created for Events',
        'taxonomies'          => array(),
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_admin_bar'   => true,
        'menu_position'       => null,
        'menu_icon'           => 'dashicons-id',
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive'         => false,  //true
        'query_var'           => true,
        'can_export'          => true,
        'rewrite'             => true,
        'capability_type'     => 'post',
        'supports'            => array( 'title', 'editor', 'thumbnail')
    );

    register_post_type( 'event', $args );
}

add_action( 'init', 'rws_event_posttype' );


add_filter('manage_event_posts_columns', 'rws_head_only_events');
add_action('manage_event_posts_custom_column', 'rws_content_only_events', 10, 2);
 
//adding column in the listing of the our mentors
function rws_head_only_events($defaults) {
    $defaults['featured_image'] = 'Event Image';
    return $defaults;
}
function rws_content_only_events($column_name, $post_ID) {
    if ($column_name == 'featured_image') {
        $post_thumbnail_id = get_post_thumbnail_id($post_ID);
        if ($post_thumbnail_id) {
            $post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'featured_preview');
            echo "<img src='".$post_thumbnail_img[0]."' width='80'/>";
        }
    }
}

// set metaboxes
function rws_events_metabox_options( $options ) {
    $options[]    = array(
        'id'        => 'event_meta',
        'title'     => 'Event Others Details',
        'post_type' => 'event',
        'context'   => 'normal',
        'priority'  => 'default',
        'sections'  => array(
            array(
                'name'  => 'general',
                //'title' => 'General',
                //'icon'  => 'fa fa-cog',
                'fields' => array(
                    array(
                        'id'        => 'event_date',
                        'type'      => 'text',
                        'title'     => 'Event Date',
                    ),
                    array(
                        'id'        => 'event_url',
                        'type'      => 'text',
                        'title'     => 'Event URL',
                    ),

                ), // END fields
            ), // END section
        ), // END sections
    ); // END $options


    return $options;
}
add_filter( 'cs_metabox_options', 'rws_events_metabox_options' );

/* adding custom metabox to set as featured */
function rws_featured_meta() {
    add_meta_box( 'rws_event_meta', __( 'Featured Posts', 'rws-iw' ), 'rws_event_meta_callback', 'event', 'side', 'high' );
}
add_action( 'add_meta_boxes', 'rws_featured_meta' );
 
/**
 * Outputs the content of the meta box
 */
 
function rws_event_meta_callback( $post ) {
    wp_nonce_field( basename( __FILE__ ), 'prfx_nonce' );
    $prfx_stored_meta = get_post_meta( $post->ID );
    ?>
 
 <p>
    <span class="prfx-row-title"><?php _e( 'Check if this is a featured post: ', 'rws-iw' )?></span>
    <div class="prfx-row-content">
        <label for="featured-checkbox">
            <input type="checkbox" name="featured-checkbox" id="featured-checkbox" value="yes" <?php if ( isset ( $prfx_stored_meta['featured-checkbox'] ) ) checked( $prfx_stored_meta['featured-checkbox'][0], 'yes' ); ?> />
            <?php _e( 'Featured Item', 'rws-iw' )?>
        </label>
 
    </div>
</p>   
 
    <?php
}
 
/**
 * Saves the custom meta input
 */
function rws_event_meta_save( $post_id ) {
 
    // Checks save status - overcome autosave, etc.
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'prfx_nonce' ] ) && wp_verify_nonce( $_POST[ 'prfx_nonce' ], basename( __FILE__ ) ) ) ? 'true' : 'false';
 
    // Exits script depending on save status
    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }
 
// Checks for input and saves - save checked as yes and unchecked at no
if( isset( $_POST[ 'featured-checkbox' ] ) ) {
    update_post_meta( $post_id, 'featured-checkbox', 'yes' );
} else {
    update_post_meta( $post_id, 'featured-checkbox', 'no' );
}
 
}
add_action( 'save_post', 'rws_event_meta_save' );
