<?php

/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
function rws_press_release_posttype() {

    $labels = array(
        'name'                => __( 'Press Releases', 'rws-iw' ),
        'singular_name'       => __( 'Press Release', 'rws-iw' ),
        'add_new'             => _x( 'Add New Press Release', 'rws-iw', 'rws-iw' ),
        'add_new_item'        => __( 'Add New Press Release', 'rws-iw' ),
        'edit_item'           => __( 'Edit Press Release', 'rws-iw' ),
        'new_item'            => __( 'New Press Release', 'rws-iw' ),
        'view_item'           => __( 'View Press Release', 'rws-iw' ),
        'search_items'        => __( 'Search Press Releases', 'rws-iw' ),
        'not_found'           => __( 'No Press Releases found', 'rws-iw' ),
        'not_found_in_trash'  => __( 'No Press Releases found in Trash', 'rws-iw' ),
        'parent_item_colon'   => __( 'Parent Press Release:', 'rws-iw' ),
        'menu_name'           => __( 'Press Releases', 'rws-iw' ),
    );

    $args = array(
        'labels'              => $labels,
        'hierarchical'        => false,
        'description'         => 'Custom Post Type Created for Press Releases',
        'taxonomies'          => array(),
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_admin_bar'   => true,
        'menu_position'       => null,
        'menu_icon'           => 'dashicons-editor-spellcheck',
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive'         => false,  //true
        'query_var'           => true,
        'can_export'          => true,
        'rewrite'             => true,
        'capability_type'     => 'post',
        'supports'            => array( 'title', 'editor', 'thumbnail', 'comments')
    );

    register_post_type( 'press-release', $args );
}

add_action( 'init', 'rws_press_release_posttype' );


add_filter('manage_press-release_posts_columns', 'rws_head_only_press_releases');
add_action('manage_press-release_posts_custom_column', 'rws_content_only_press_releases', 10, 2);
 
//adding column in the listing of the our mentors
function rws_head_only_press_releases($defaults) {
    $defaults['featured_image'] = 'Press Release Image';
    return $defaults;
}
function rws_content_only_press_releases($column_name, $post_ID) {
    if ($column_name == 'featured_image') {
        $post_thumbnail_id = get_post_thumbnail_id($post_ID);
        if ($post_thumbnail_id) {
            $post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'featured_preview');
            echo "<img src='".$post_thumbnail_img[0]."' width='80'/>";
        }
    }
}

// set metaboxes
function rws_press_releases_metabox_options( $options ) {
    $options[]    = array(
        'id'        => 'press_release_meta',
        'title'     => 'Press Release Others Details',
        'post_type' => 'press-release',
        'context'   => 'normal',
        'priority'  => 'default',
        'sections'  => array(
            array(
                'name'  => 'general',
                //'title' => 'General',
                //'icon'  => 'fa fa-cog',
                'fields' => array(
                    array(
                        'id'        => 'press_release_date',
                        'type'      => 'text',
                        'title'     => 'Press Release Date',
                    ),
                    array(
                        'id'        => 'press_release_url',
                        'type'      => 'text',
                        'title'     => 'Press Release URL',
                    ),

                ), // END fields
            ), // END section
        ), // END sections
    ); // END $options


    return $options;
}
//add_filter( 'cs_metabox_options', 'rws_press_releases_metabox_options' );