<?php

/**
* Registers a new post type
* @uses $wp_post_types Inserts new post type object into the list
*
* @param string  Post type key, must not exceed 20 characters
* @param array|string  See optional args description above.
* @return object|WP_Error the registered post type object, or an error object
*/
function rws_sponsor_release_posttype() {

    $labels = array(
        'name'                => __( 'Sponsors', 'rws-iw' ),
        'singular_name'       => __( 'Sponsor', 'rws-iw' ),
        'add_new'             => _x( 'Add New Sponsor', 'rws-iw', 'rws-iw' ),
        'add_new_item'        => __( 'Add New Sponsor', 'rws-iw' ),
        'edit_item'           => __( 'Edit Sponsor', 'rws-iw' ),
        'new_item'            => __( 'New Sponsor', 'rws-iw' ),
        'view_item'           => __( 'View Sponsor', 'rws-iw' ),
        'search_items'        => __( 'Search Sponsors', 'rws-iw' ),
        'not_found'           => __( 'No Sponsors found', 'rws-iw' ),
        'not_found_in_trash'  => __( 'No Sponsors found in Trash', 'rws-iw' ),
        'parent_item_colon'   => __( 'Parent Sponsor:', 'rws-iw' ),
        'menu_name'           => __( 'Sponsors', 'rws-iw' ),
    );

    $args = array(
        'labels'              => $labels,
        'hierarchical'        => false,
        'description'         => 'Custom Post Type Created for Press Releases',
        'taxonomies'          => array(),
        'public'              => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_admin_bar'   => true,
        'menu_position'       => null,
        'menu_icon'           => 'dashicons-editor-spellcheck',
        'show_in_nav_menus'   => true,
        'publicly_queryable'  => true,
        'exclude_from_search' => false,
        'has_archive'         => false,  //true
        'query_var'           => true,
        'can_export'          => true,
        'rewrite'             => true,
        'capability_type'     => 'post',
        'supports'            => array( 'title', 'editor', 'thumbnail', 'comments')
    );

    register_post_type( 'sponsor', $args );
}

add_action( 'init', 'rws_sponsor_release_posttype' );


/**
 * Create a taxonomy
 *
 * @uses  Inserts new taxonomy object into the list
 * @uses  Adds query vars
 *
 * @param string  Name of taxonomy object
 * @param array|string  Name of the object type for the taxonomy object.
 * @param array|string  Taxonomy arguments
 * @return null|WP_Error WP_Error if errors, otherwise null.
 */
function rws_sponsor_release_taxonomy() {

    $labels = array(
        'name'                  => _x( 'Sponsors Categories', 'Taxonomy plural name', 'rws-iw' ),
        'singular_name'         => _x( 'Sponsor Category', 'Taxonomy singular name', 'rws-iw' ),
        'search_items'          => __( 'Search Sponsors Categories', 'rws-iw' ),
        'popular_items'         => __( 'Popular Sponsors Categories', 'rws-iw' ),
        'all_items'             => __( 'All Sponsors Categories', 'rws-iw' ),
        'parent_item'           => __( 'Parent Sponsor Category', 'rws-iw' ),
        'parent_item_colon'     => __( 'Parent Sponsor Category', 'rws-iw' ),
        'edit_item'             => __( 'Edit Sponsor Category', 'rws-iw' ),
        'update_item'           => __( 'Update Sponsor Category', 'rws-iw' ),
        'add_new_item'          => __( 'Add New Sponsor Category', 'rws-iw' ),
        'new_item_name'         => __( 'New Sponsor Category Name', 'rws-iw' ),
        'add_or_remove_items'   => __( 'Add or remove Sponsors Categories', 'rws-iw' ),
        'choose_from_most_used' => __( 'Choose from most used Sponsors Categories', 'rws-iw' ),
        'menu_name'             => __( 'Sponsor Category', 'rws-iw' ),
    );

    $args = array(
        'labels'            => $labels,
        'public'            => true,
        'show_in_nav_menus' => true,
        'show_admin_column' => false,
        'hierarchical'      => true,
        'show_tagcloud'     => true,
        'show_ui'           => true,
        'query_var'         => true,
        'rewrite'           => true,
        'query_var'         => true,
        'capabilities'      => array(),
    );

    register_taxonomy( 'sponsor-category', array( 'sponsor' ), $args );
}

add_action( 'init', 'rws_sponsor_release_taxonomy' );